"""
    Workload API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.workload_v1_api import WorkloadV1Api  # noqa: E501


class TestWorkloadV1Api(unittest.TestCase):
    """WorkloadV1Api unit test stubs"""

    def setUp(self):
        self.api = WorkloadV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_abort_migration(self):
        """Test case for abort_migration

        Abort Workload Migration operation  # noqa: E501
        """
        pass

    def test_abort_migration1(self):
        """Test case for abort_migration1

        Abort Workload Migration operation  # noqa: E501
        """
        pass

    def test_add_workload(self):
        """Test case for add_workload

        Create Workload object  # noqa: E501
        """
        pass

    def test_add_workload1(self):
        """Test case for add_workload1

        Create Workload object  # noqa: E501
        """
        pass

    def test_add_workload_group(self):
        """Test case for add_workload_group

        Create WorkloadGroup object  # noqa: E501
        """
        pass

    def test_add_workload_group1(self):
        """Test case for add_workload_group1

        Create WorkloadGroup object  # noqa: E501
        """
        pass

    def test_delete_workload(self):
        """Test case for delete_workload

        Delete Workload object  # noqa: E501
        """
        pass

    def test_delete_workload1(self):
        """Test case for delete_workload1

        Delete Workload object  # noqa: E501
        """
        pass

    def test_delete_workload_group(self):
        """Test case for delete_workload_group

        Delete WorkloadGroup object  # noqa: E501
        """
        pass

    def test_delete_workload_group1(self):
        """Test case for delete_workload_group1

        Delete WorkloadGroup object  # noqa: E501
        """
        pass

    def test_final_sync_migration(self):
        """Test case for final_sync_migration

        Initiates the final sync for the Workload Migration operation  # noqa: E501
        """
        pass

    def test_final_sync_migration1(self):
        """Test case for final_sync_migration1

        Initiates the final sync for the Workload Migration operation  # noqa: E501
        """
        pass

    def test_finish_migration(self):
        """Test case for finish_migration

        Finish Workload Migration operation  # noqa: E501
        """
        pass

    def test_finish_migration1(self):
        """Test case for finish_migration1

        Finish Workload Migration operation  # noqa: E501
        """
        pass

    def test_get_endpoint(self):
        """Test case for get_endpoint

        Get Endpoint object  # noqa: E501
        """
        pass

    def test_get_endpoint1(self):
        """Test case for get_endpoint1

        Get Endpoint object  # noqa: E501
        """
        pass

    def test_get_workload(self):
        """Test case for get_workload

        Get Workload object  # noqa: E501
        """
        pass

    def test_get_workload1(self):
        """Test case for get_workload1

        Get Workload object  # noqa: E501
        """
        pass

    def test_get_workload_group(self):
        """Test case for get_workload_group

        Get WorkloadGroup object  # noqa: E501
        """
        pass

    def test_get_workload_group1(self):
        """Test case for get_workload_group1

        Get WorkloadGroup object  # noqa: E501
        """
        pass

    def test_label_workload(self):
        """Test case for label_workload

        Label Workload object  # noqa: E501
        """
        pass

    def test_label_workload1(self):
        """Test case for label_workload1

        Label Workload object  # noqa: E501
        """
        pass

    def test_label_workload_group(self):
        """Test case for label_workload_group

        Label WorkloadGroup object  # noqa: E501
        """
        pass

    def test_label_workload_group1(self):
        """Test case for label_workload_group1

        Label WorkloadGroup object  # noqa: E501
        """
        pass

    def test_list_endpoint(self):
        """Test case for list_endpoint

        List Endpoint objects  # noqa: E501
        """
        pass

    def test_list_endpoint1(self):
        """Test case for list_endpoint1

        List Endpoint objects  # noqa: E501
        """
        pass

    def test_list_workload(self):
        """Test case for list_workload

        List Workload objects  # noqa: E501
        """
        pass

    def test_list_workload1(self):
        """Test case for list_workload1

        List Workload objects  # noqa: E501
        """
        pass

    def test_list_workload_group(self):
        """Test case for list_workload_group

        List WorkloadGroup objects  # noqa: E501
        """
        pass

    def test_list_workload_group1(self):
        """Test case for list_workload_group1

        List WorkloadGroup objects  # noqa: E501
        """
        pass

    def test_start_migration(self):
        """Test case for start_migration

        Start Workload Migration operation  # noqa: E501
        """
        pass

    def test_start_migration1(self):
        """Test case for start_migration1

        Start Workload Migration operation  # noqa: E501
        """
        pass

    def test_update_workload(self):
        """Test case for update_workload

        Update Workload object  # noqa: E501
        """
        pass

    def test_update_workload1(self):
        """Test case for update_workload1

        Update Workload object  # noqa: E501
        """
        pass

    def test_update_workload_group(self):
        """Test case for update_workload_group

        Update WorkloadGroup object  # noqa: E501
        """
        pass

    def test_update_workload_group1(self):
        """Test case for update_workload_group1

        Update WorkloadGroup object  # noqa: E501
        """
        pass

    def test_watch_endpoint(self):
        """Test case for watch_endpoint

        Watch Endpoint objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_endpoint1(self):
        """Test case for watch_endpoint1

        Watch Endpoint objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_workload(self):
        """Test case for watch_workload

        Watch Workload objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_workload1(self):
        """Test case for watch_workload1

        Watch Workload objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_workload_group(self):
        """Test case for watch_workload_group

        Watch WorkloadGroup objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_workload_group1(self):
        """Test case for watch_workload_group1

        Watch WorkloadGroup objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Workload API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""



import os
import time
import requests
import json
from dateutil.parser import parse as dateutil_parser
import psm
from psm.models import *
from pprint import pprint
from psm.api import *
from api import workload_v1_api
from pensando_dss.psm.model.api_label import ApiLabel
from pensando_dss.psm.model.api_status import ApiStatus
from pensando_dss.psm.model.workload_auto_msg_endpoint_watch_helper import WorkloadAutoMsgEndpointWatchHelper
from pensando_dss.psm.model.workload_auto_msg_workload_group_watch_helper import WorkloadAutoMsgWorkloadGroupWatchHelper
from pensando_dss.psm.model.workload_auto_msg_workload_watch_helper import WorkloadAutoMsgWorkloadWatchHelper
from pensando_dss.psm.model.workload_endpoint import WorkloadEndpoint
from pensando_dss.psm.model.workload_endpoint_list import WorkloadEndpointList
from pensando_dss.psm.model.workload_workload import WorkloadWorkload
from pensando_dss.psm.model.workload_workload_group import WorkloadWorkloadGroup
from pensando_dss.psm.model.workload_workload_group_list import WorkloadWorkloadGroupList
from pensando_dss.psm.model.workload_workload_list import WorkloadWorkloadList

HOME = os.environ["HOME"]
# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = pensando_dss.psm.Configuration(
    psm_config_path = os.environ["HOME"] + "/.psm/config.json"
)
configuration.verify_ssl = False



# Enter a context with an instance of the API client
with psm.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = workload_v1_api.WorkloadV1Api(api_client)
    o_tenant = "O.Tenant_example" # str | 
body = WorkloadWorkload(
        api_version="api_version_example",
        kind="kind_example",
        meta=ApiObjectMeta(
            creation_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
            display_name="g6bUUGjjNSwg0_bs9ZayIMrKdgNvb",
            generation_id="generation_id_example",
            labels={
                "key": "key_example",
            },
            mod_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
            name="name_example",
            namespace="namespace_example",
            resource_version="resource_version_example",
            self_link="self_link_example",
            tenant="tenant_example",
            uuid="uuid_example",
        ),
        spec=WorkloadWorkloadSpec(
            host_name="host_name_example",
            interfaces=[
                WorkloadWorkloadIntfSpec(
                    dsc_interfaces=[
                        "dsc_interfaces_example",
                    ],
                    external_vlan=0,
                    ip_addresses=[
                        "ip_addresses_example",
                    ],
                    mac_address="aabb.ccdd.0000, aabb.ccdd.0000, aabb.ccdd.0000",
                    micro_seg_vlan=0,
                    network="network_example",
                    vni=1,
                ),
            ],
            migration_timeout="60s",
        ),
        status=WorkloadWorkloadStatus(
            host_name="host_name_example",
            interfaces=[
                WorkloadWorkloadIntfStatus(
                    dsc_interfaces=[
                        "dsc_interfaces_example",
                    ],
                    endpoint="endpoint_example",
                    external_vlan=1,
                    ip_addresses=[
                        "ip_addresses_example",
                    ],
                    mac_address="mac_address_example",
                    micro_seg_vlan=1,
                    network="network_example",
                    pending_workload_groups=[
                        "pending_workload_groups_example",
                    ],
                    vni=1,
                    workload_groups=[
                        "workload_groups_example",
                    ],
                ),
            ],
            migration_status=WorkloadWorkloadMigrationStatus(
                completed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                flow_migration_status=[
                    WorkloadInterfaceMigrationStatus(
                        errors=[
                            "errors_example",
                        ],
                        ip_addresses="ip_addresses_example",
                        mac_address="mac_address_example",
                    ),
                ],
                from_host_name="from_host_name_example",
                migration_id="migration_id_example",
                migration_transaction_id=1,
                stage="migration-none",
                started_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                status="none",
                to_host_name="to_host_name_example",
            ),
            mirror_sessions=[
                "mirror_sessions_example",
            ],
            propagation_status=WorkloadPropagationStatus(
                endpoint_prop_status=[
                    WorkloadEndpointPropStatus(
                        dse_status=[
                            ApiDSEStatus(
                                dse_id="dse_id_example",
                                dse_info_status="dse_info_status_example",
                            ),
                        ],
                        generation_id="generation_id_example",
                        mac_address="mac_address_example",
                        name="name_example",
                        pending=1,
                        pending_dses=[
                            "pending_dses_example",
                        ],
                        status="status_example",
                        updated=1,
                    ),
                ],
                status="status_example",
            ),
            workload_groups=[],
        ),
    ) # WorkloadWorkload | 

    try:
        # Abort Workload Migration operation
        api_response = api_instance.abort_migration(o_tenant, body)
        pprint(api_response)
    except psm.ApiException as e:
        print("Exception when calling WorkloadV1Api->abort_migration: %s\n" % e)



"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.security_certificate import SecurityCertificate
globals()['SecurityCertificate'] = SecurityCertificate
from pensando_dss.psm.psm.model.security_auto_msg_certificate_watch_helper_watch_event import SecurityAutoMsgCertificateWatchHelperWatchEvent


class TestSecurityAutoMsgCertificateWatchHelperWatchEvent(unittest.TestCase):
    """SecurityAutoMsgCertificateWatchHelperWatchEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecurityAutoMsgCertificateWatchHelperWatchEvent(self):
        """Test SecurityAutoMsgCertificateWatchHelperWatchEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecurityAutoMsgCertificateWatchHelperWatchEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Orchestration API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.orchestration_orchestrator import OrchestrationOrchestrator
globals()['OrchestrationOrchestrator'] = OrchestrationOrchestrator
from pensando_dss.psm.psm.model.orchestration_auto_msg_orchestrator_watch_helper_watch_event import OrchestrationAutoMsgOrchestratorWatchHelperWatchEvent


class TestOrchestrationAutoMsgOrchestratorWatchHelperWatchEvent(unittest.TestCase):
    """OrchestrationAutoMsgOrchestratorWatchHelperWatchEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOrchestrationAutoMsgOrchestratorWatchHelperWatchEvent(self):
        """Test OrchestrationAutoMsgOrchestratorWatchHelperWatchEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = OrchestrationAutoMsgOrchestratorWatchHelperWatchEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from psm.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from pensando_dss.psm.model.api_agg_watch_options import ApiAggWatchOptions
from pensando_dss.psm.model.api_kind_watch_options import ApiKindWatchOptions
from pensando_dss.psm.model.api_label import ApiLabel
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.api_list_watch_options import ApiListWatchOptions
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.api_object_ref import ApiObjectRef
from pensando_dss.psm.model.api_status import ApiStatus
from pensando_dss.psm.model.api_status_result import ApiStatusResult
from pensando_dss.psm.model.api_timestamp import ApiTimestamp
from pensando_dss.psm.model.api_type_meta import ApiTypeMeta
from pensando_dss.psm.model.api_watch_control import ApiWatchControl
from pensando_dss.psm.model.api_watch_event import ApiWatchEvent
from pensando_dss.psm.model.api_watch_event_list import ApiWatchEventList
from pensando_dss.psm.model.fields_requirement import FieldsRequirement
from pensando_dss.psm.model.fields_selector import FieldsSelector
from pensando_dss.psm.model.googleprotobuf_any import GoogleprotobufAny
from pensando_dss.psm.model.labels_requirement import LabelsRequirement
from pensando_dss.psm.model.labels_selector import LabelsSelector
from pensando_dss.psm.model.monitoring_alert import MonitoringAlert
from pensando_dss.psm.model.monitoring_alert_destination import MonitoringAlertDestination
from pensando_dss.psm.model.monitoring_alert_destination_list import MonitoringAlertDestinationList
from pensando_dss.psm.model.monitoring_alert_destination_spec import MonitoringAlertDestinationSpec
from pensando_dss.psm.model.monitoring_alert_destination_status import MonitoringAlertDestinationStatus
from pensando_dss.psm.model.monitoring_alert_list import MonitoringAlertList
from pensando_dss.psm.model.monitoring_alert_policy import MonitoringAlertPolicy
from pensando_dss.psm.model.monitoring_alert_policy_list import MonitoringAlertPolicyList
from pensando_dss.psm.model.monitoring_alert_policy_spec import MonitoringAlertPolicySpec
from pensando_dss.psm.model.monitoring_alert_policy_status import MonitoringAlertPolicyStatus
from pensando_dss.psm.model.monitoring_alert_reason import MonitoringAlertReason
from pensando_dss.psm.model.monitoring_alert_source import MonitoringAlertSource
from pensando_dss.psm.model.monitoring_alert_spec import MonitoringAlertSpec
from pensando_dss.psm.model.monitoring_alert_status import MonitoringAlertStatus
from pensando_dss.psm.model.monitoring_app_proto_selector import MonitoringAppProtoSelector
from pensando_dss.psm.model.monitoring_archive_query import MonitoringArchiveQuery
from pensando_dss.psm.model.monitoring_archive_request import MonitoringArchiveRequest
from pensando_dss.psm.model.monitoring_archive_request_list import MonitoringArchiveRequestList
from pensando_dss.psm.model.monitoring_archive_request_spec import MonitoringArchiveRequestSpec
from pensando_dss.psm.model.monitoring_archive_request_status import MonitoringArchiveRequestStatus
from pensando_dss.psm.model.monitoring_audit_info import MonitoringAuditInfo
from pensando_dss.psm.model.monitoring_audit_policy import MonitoringAuditPolicy
from pensando_dss.psm.model.monitoring_audit_policy_list import MonitoringAuditPolicyList
from pensando_dss.psm.model.monitoring_audit_policy_spec import MonitoringAuditPolicySpec
from pensando_dss.psm.model.monitoring_auth_config import MonitoringAuthConfig
from pensando_dss.psm.model.monitoring_auto_msg_alert_destination_watch_helper import MonitoringAutoMsgAlertDestinationWatchHelper
from pensando_dss.psm.model.monitoring_auto_msg_alert_destination_watch_helper_watch_event import MonitoringAutoMsgAlertDestinationWatchHelperWatchEvent
from pensando_dss.psm.model.monitoring_auto_msg_alert_policy_watch_helper import MonitoringAutoMsgAlertPolicyWatchHelper
from pensando_dss.psm.model.monitoring_auto_msg_alert_policy_watch_helper_watch_event import MonitoringAutoMsgAlertPolicyWatchHelperWatchEvent
from pensando_dss.psm.model.monitoring_auto_msg_alert_watch_helper import MonitoringAutoMsgAlertWatchHelper
from pensando_dss.psm.model.monitoring_auto_msg_alert_watch_helper_watch_event import MonitoringAutoMsgAlertWatchHelperWatchEvent
from pensando_dss.psm.model.monitoring_auto_msg_archive_request_watch_helper import MonitoringAutoMsgArchiveRequestWatchHelper
from pensando_dss.psm.model.monitoring_auto_msg_archive_request_watch_helper_watch_event import MonitoringAutoMsgArchiveRequestWatchHelperWatchEvent
from pensando_dss.psm.model.monitoring_auto_msg_audit_policy_watch_helper import MonitoringAutoMsgAuditPolicyWatchHelper
from pensando_dss.psm.model.monitoring_auto_msg_audit_policy_watch_helper_watch_event import MonitoringAutoMsgAuditPolicyWatchHelperWatchEvent
from pensando_dss.psm.model.monitoring_auto_msg_event_policy_watch_helper import MonitoringAutoMsgEventPolicyWatchHelper
from pensando_dss.psm.model.monitoring_auto_msg_event_policy_watch_helper_watch_event import MonitoringAutoMsgEventPolicyWatchHelperWatchEvent
from pensando_dss.psm.model.monitoring_auto_msg_flow_export_policy_watch_helper import MonitoringAutoMsgFlowExportPolicyWatchHelper
from pensando_dss.psm.model.monitoring_auto_msg_flow_export_policy_watch_helper_watch_event import MonitoringAutoMsgFlowExportPolicyWatchHelperWatchEvent
from pensando_dss.psm.model.monitoring_auto_msg_fwlog_policy_watch_helper import MonitoringAutoMsgFwlogPolicyWatchHelper
from pensando_dss.psm.model.monitoring_auto_msg_fwlog_policy_watch_helper_watch_event import MonitoringAutoMsgFwlogPolicyWatchHelperWatchEvent
from pensando_dss.psm.model.monitoring_auto_msg_mirror_session_watch_helper import MonitoringAutoMsgMirrorSessionWatchHelper
from pensando_dss.psm.model.monitoring_auto_msg_mirror_session_watch_helper_watch_event import MonitoringAutoMsgMirrorSessionWatchHelperWatchEvent
from pensando_dss.psm.model.monitoring_auto_msg_stats_alert_policy_watch_helper import MonitoringAutoMsgStatsAlertPolicyWatchHelper
from pensando_dss.psm.model.monitoring_auto_msg_stats_alert_policy_watch_helper_watch_event import MonitoringAutoMsgStatsAlertPolicyWatchHelperWatchEvent
from pensando_dss.psm.model.monitoring_auto_msg_tech_support_request_watch_helper import MonitoringAutoMsgTechSupportRequestWatchHelper
from pensando_dss.psm.model.monitoring_auto_msg_tech_support_request_watch_helper_watch_event import MonitoringAutoMsgTechSupportRequestWatchHelperWatchEvent
from pensando_dss.psm.model.monitoring_auto_msg_troubleshooting_session_watch_helper import MonitoringAutoMsgTroubleshootingSessionWatchHelper
from pensando_dss.psm.model.monitoring_auto_msg_troubleshooting_session_watch_helper_watch_event import MonitoringAutoMsgTroubleshootingSessionWatchHelperWatchEvent
from pensando_dss.psm.model.monitoring_cancel_archive_request import MonitoringCancelArchiveRequest
from pensando_dss.psm.model.monitoring_dsc_status import MonitoringDSCStatus
from pensando_dss.psm.model.monitoring_email_export import MonitoringEmailExport
from pensando_dss.psm.model.monitoring_event_policy import MonitoringEventPolicy
from pensando_dss.psm.model.monitoring_event_policy_list import MonitoringEventPolicyList
from pensando_dss.psm.model.monitoring_event_policy_spec import MonitoringEventPolicySpec
from pensando_dss.psm.model.monitoring_export_config import MonitoringExportConfig
from pensando_dss.psm.model.monitoring_flow_export_policy import MonitoringFlowExportPolicy
from pensando_dss.psm.model.monitoring_flow_export_policy_list import MonitoringFlowExportPolicyList
from pensando_dss.psm.model.monitoring_flow_export_policy_spec import MonitoringFlowExportPolicySpec
from pensando_dss.psm.model.monitoring_flow_export_policy_status import MonitoringFlowExportPolicyStatus
from pensando_dss.psm.model.monitoring_fwlog_policy import MonitoringFwlogPolicy
from pensando_dss.psm.model.monitoring_fwlog_policy_list import MonitoringFwlogPolicyList
from pensando_dss.psm.model.monitoring_fwlog_policy_spec import MonitoringFwlogPolicySpec
from pensando_dss.psm.model.monitoring_instance_selector import MonitoringInstanceSelector
from pensando_dss.psm.model.monitoring_interface_mirror import MonitoringInterfaceMirror
from pensando_dss.psm.model.monitoring_match_rule import MonitoringMatchRule
from pensando_dss.psm.model.monitoring_match_selector import MonitoringMatchSelector
from pensando_dss.psm.model.monitoring_matched_requirement import MonitoringMatchedRequirement
from pensando_dss.psm.model.monitoring_measurement_criteria import MonitoringMeasurementCriteria
from pensando_dss.psm.model.monitoring_metric_identifier import MonitoringMetricIdentifier
from pensando_dss.psm.model.monitoring_mirror_collector import MonitoringMirrorCollector
from pensando_dss.psm.model.monitoring_mirror_export_config import MonitoringMirrorExportConfig
from pensando_dss.psm.model.monitoring_mirror_session import MonitoringMirrorSession
from pensando_dss.psm.model.monitoring_mirror_session_list import MonitoringMirrorSessionList
from pensando_dss.psm.model.monitoring_mirror_session_spec import MonitoringMirrorSessionSpec
from pensando_dss.psm.model.monitoring_mirror_session_status import MonitoringMirrorSessionStatus
from pensando_dss.psm.model.monitoring_mirror_source import MonitoringMirrorSource
from pensando_dss.psm.model.monitoring_mirror_start_conditions import MonitoringMirrorStartConditions
from pensando_dss.psm.model.monitoring_psm_export_target import MonitoringPSMExportTarget
from pensando_dss.psm.model.monitoring_privacy_config import MonitoringPrivacyConfig
from pensando_dss.psm.model.monitoring_propagation_status import MonitoringPropagationStatus
from pensando_dss.psm.model.monitoring_snmp_export import MonitoringSNMPExport
from pensando_dss.psm.model.monitoring_snmp_trap_server import MonitoringSNMPTrapServer
from pensando_dss.psm.model.monitoring_stats_alert_policy import MonitoringStatsAlertPolicy
from pensando_dss.psm.model.monitoring_stats_alert_policy_list import MonitoringStatsAlertPolicyList
from pensando_dss.psm.model.monitoring_stats_alert_policy_spec import MonitoringStatsAlertPolicySpec
from pensando_dss.psm.model.monitoring_stats_alert_policy_status import MonitoringStatsAlertPolicyStatus
from pensando_dss.psm.model.monitoring_syslog_auditor import MonitoringSyslogAuditor
from pensando_dss.psm.model.monitoring_syslog_export import MonitoringSyslogExport
from pensando_dss.psm.model.monitoring_syslog_export_config import MonitoringSyslogExportConfig
from pensando_dss.psm.model.monitoring_tech_support_node_result import MonitoringTechSupportNodeResult
from pensando_dss.psm.model.monitoring_tech_support_request import MonitoringTechSupportRequest
from pensando_dss.psm.model.monitoring_tech_support_request_list import MonitoringTechSupportRequestList
from pensando_dss.psm.model.monitoring_tech_support_request_spec import MonitoringTechSupportRequestSpec
from pensando_dss.psm.model.monitoring_tech_support_request_status import MonitoringTechSupportRequestStatus
from pensando_dss.psm.model.monitoring_threshold import MonitoringThreshold
from pensando_dss.psm.model.monitoring_thresholds import MonitoringThresholds
from pensando_dss.psm.model.monitoring_time_window import MonitoringTimeWindow
from pensando_dss.psm.model.monitoring_troubleshooting_session import MonitoringTroubleshootingSession
from pensando_dss.psm.model.monitoring_troubleshooting_session_list import MonitoringTroubleshootingSessionList
from pensando_dss.psm.model.monitoring_troubleshooting_session_spec import MonitoringTroubleshootingSessionSpec
from pensando_dss.psm.model.monitoring_troubleshooting_session_status import MonitoringTroubleshootingSessionStatus
from pensando_dss.psm.model.monitoring_ts_result import MonitoringTsResult
from pensando_dss.psm.model.monitoring_workload_mirror import MonitoringWorkloadMirror
from pensando_dss.psm.model.search_text_requirement import SearchTextRequirement
from pensando_dss.psm.model.tech_support_request_spec_node_selector_spec import TechSupportRequestSpecNodeSelectorSpec



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from psm.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from pensando_dss.psm.model.api_agg_watch_options import ApiAggWatchOptions
from pensando_dss.psm.model.api_kind_watch_options import ApiKindWatchOptions
from pensando_dss.psm.model.api_label import ApiLabel
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.api_list_watch_options import ApiListWatchOptions
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.api_object_ref import ApiObjectRef
from pensando_dss.psm.model.api_status import ApiStatus
from pensando_dss.psm.model.api_status_result import ApiStatusResult
from pensando_dss.psm.model.api_timestamp import ApiTimestamp
from pensando_dss.psm.model.api_type_meta import ApiTypeMeta
from pensando_dss.psm.model.api_watch_control import ApiWatchControl
from pensando_dss.psm.model.api_watch_event import ApiWatchEvent
from pensando_dss.psm.model.api_watch_event_list import ApiWatchEventList
from pensando_dss.psm.model.googleprotobuf_any import GoogleprotobufAny
from pensando_dss.psm.model.objstore_auto_msg_bucket_watch_helper import ObjstoreAutoMsgBucketWatchHelper
from pensando_dss.psm.model.objstore_auto_msg_bucket_watch_helper_watch_event import ObjstoreAutoMsgBucketWatchHelperWatchEvent
from pensando_dss.psm.model.objstore_auto_msg_object_watch_helper import ObjstoreAutoMsgObjectWatchHelper
from pensando_dss.psm.model.objstore_auto_msg_object_watch_helper_watch_event import ObjstoreAutoMsgObjectWatchHelperWatchEvent
from pensando_dss.psm.model.objstore_bucket import ObjstoreBucket
from pensando_dss.psm.model.objstore_bucket_list import ObjstoreBucketList
from pensando_dss.psm.model.objstore_bucket_spec import ObjstoreBucketSpec
from pensando_dss.psm.model.objstore_bucket_status import ObjstoreBucketStatus
from pensando_dss.psm.model.objstore_object import ObjstoreObject
from pensando_dss.psm.model.objstore_object_list import ObjstoreObjectList
from pensando_dss.psm.model.objstore_object_spec import ObjstoreObjectSpec
from pensando_dss.psm.model.objstore_object_status import ObjstoreObjectStatus
from pensando_dss.psm.model.objstore_stream_chunk import ObjstoreStreamChunk



"""
    Tokenauth API reference

    APIs to generate node auth tokens    # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.tokenauth_v1_api import TokenauthV1Api  # noqa: E501


class TestTokenauthV1Api(unittest.TestCase):
    """TokenauthV1Api unit test stubs"""

    def setUp(self):
        self.api = TokenauthV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_generate_node_token(self):
        """Test case for get_generate_node_token

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Routing API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.routing_v1_api import RoutingV1Api  # noqa: E501


class TestRoutingV1Api(unittest.TestCase):
    """RoutingV1Api unit test stubs"""

    def setUp(self):
        self.api = RoutingV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_health_z(self):
        """Test case for get_health_z

        """
        pass

    def test_get_list_neighbors(self):
        """Test case for get_list_neighbors

        """
        pass

    def test_get_list_routes1(self):
        """Test case for get_list_routes1

        """
        pass

    def test_post_list_routes(self):
        """Test case for post_list_routes

        """
        pass


if __name__ == '__main__':
    unittest.main()



import importlib
import os

from os import listdir
from os.path import isfile, join

ownpath = __file__.replace("__init__.py", "")

__all__ = [ name for name in os.listdir(ownpath) if (os.path.isdir(os.path.join(ownpath, name)) and not name.startswith("_")) ]

for i in __all__:
    module = importlib.import_module('.'+i, "pensando_dss.psm.apis")
    globals().update(
        {n: getattr(module, n) for n in module.__all__} if hasattr(module, '__all__') 
        else 
        {k: v for (k, v) in module.__dict__.items() if not k.startswith('_')
    })



"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.network_virtual_router_peering_group import NetworkVirtualRouterPeeringGroup
globals()['ApiListMeta'] = ApiListMeta
globals()['NetworkVirtualRouterPeeringGroup'] = NetworkVirtualRouterPeeringGroup
from pensando_dss.psm.psm.model.network_virtual_router_peering_group_list import NetworkVirtualRouterPeeringGroupList


class TestNetworkVirtualRouterPeeringGroupList(unittest.TestCase):
    """NetworkVirtualRouterPeeringGroupList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkVirtualRouterPeeringGroupList(self):
        """Test NetworkVirtualRouterPeeringGroupList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkVirtualRouterPeeringGroupList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Search API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.search_error import SearchError
from pensando_dss.psm.model.search_rules_by_policy_name import SearchRulesByPolicyName
globals()['SearchError'] = SearchError
globals()['SearchRulesByPolicyName'] = SearchRulesByPolicyName
from pensando_dss.psm.psm.model.search_policy_search_response import SearchPolicySearchResponse


class TestSearchPolicySearchResponse(unittest.TestCase):
    """SearchPolicySearchResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSearchPolicySearchResponse(self):
        """Test SearchPolicySearchResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SearchPolicySearchResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from psm.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from pensando_dss.psm.model.api_agg_watch_options import ApiAggWatchOptions
from pensando_dss.psm.model.api_kind_watch_options import ApiKindWatchOptions
from pensando_dss.psm.model.api_label import ApiLabel
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.api_list_watch_options import ApiListWatchOptions
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.api_object_ref import ApiObjectRef
from pensando_dss.psm.model.api_status import ApiStatus
from pensando_dss.psm.model.api_status_result import ApiStatusResult
from pensando_dss.psm.model.api_timestamp import ApiTimestamp
from pensando_dss.psm.model.api_type_meta import ApiTypeMeta
from pensando_dss.psm.model.api_watch_control import ApiWatchControl
from pensando_dss.psm.model.api_watch_event import ApiWatchEvent
from pensando_dss.psm.model.api_watch_event_list import ApiWatchEventList
from pensando_dss.psm.model.cluster_auto_msg_cluster_profile_watch_helper import ClusterAutoMsgClusterProfileWatchHelper
from pensando_dss.psm.model.cluster_auto_msg_cluster_profile_watch_helper_watch_event import ClusterAutoMsgClusterProfileWatchHelperWatchEvent
from pensando_dss.psm.model.cluster_auto_msg_cluster_watch_helper import ClusterAutoMsgClusterWatchHelper
from pensando_dss.psm.model.cluster_auto_msg_cluster_watch_helper_watch_event import ClusterAutoMsgClusterWatchHelperWatchEvent
from pensando_dss.psm.model.cluster_auto_msg_configuration_snapshot_watch_helper import ClusterAutoMsgConfigurationSnapshotWatchHelper
from pensando_dss.psm.model.cluster_auto_msg_configuration_snapshot_watch_helper_watch_event import ClusterAutoMsgConfigurationSnapshotWatchHelperWatchEvent
from pensando_dss.psm.model.cluster_auto_msg_credentials_watch_helper import ClusterAutoMsgCredentialsWatchHelper
from pensando_dss.psm.model.cluster_auto_msg_credentials_watch_helper_watch_event import ClusterAutoMsgCredentialsWatchHelperWatchEvent
from pensando_dss.psm.model.cluster_auto_msg_dsc_profile_watch_helper import ClusterAutoMsgDSCProfileWatchHelper
from pensando_dss.psm.model.cluster_auto_msg_dsc_profile_watch_helper_watch_event import ClusterAutoMsgDSCProfileWatchHelperWatchEvent
from pensando_dss.psm.model.cluster_auto_msg_distributed_service_card_watch_helper import ClusterAutoMsgDistributedServiceCardWatchHelper
from pensando_dss.psm.model.cluster_auto_msg_distributed_service_card_watch_helper_watch_event import ClusterAutoMsgDistributedServiceCardWatchHelperWatchEvent
from pensando_dss.psm.model.cluster_auto_msg_distributed_service_entity_watch_helper import ClusterAutoMsgDistributedServiceEntityWatchHelper
from pensando_dss.psm.model.cluster_auto_msg_distributed_service_entity_watch_helper_watch_event import ClusterAutoMsgDistributedServiceEntityWatchHelperWatchEvent
from pensando_dss.psm.model.cluster_auto_msg_host_watch_helper import ClusterAutoMsgHostWatchHelper
from pensando_dss.psm.model.cluster_auto_msg_host_watch_helper_watch_event import ClusterAutoMsgHostWatchHelperWatchEvent
from pensando_dss.psm.model.cluster_auto_msg_license_watch_helper import ClusterAutoMsgLicenseWatchHelper
from pensando_dss.psm.model.cluster_auto_msg_license_watch_helper_watch_event import ClusterAutoMsgLicenseWatchHelperWatchEvent
from pensando_dss.psm.model.cluster_auto_msg_node_watch_helper import ClusterAutoMsgNodeWatchHelper
from pensando_dss.psm.model.cluster_auto_msg_node_watch_helper_watch_event import ClusterAutoMsgNodeWatchHelperWatchEvent
from pensando_dss.psm.model.cluster_auto_msg_snapshot_restore_watch_helper import ClusterAutoMsgSnapshotRestoreWatchHelper
from pensando_dss.psm.model.cluster_auto_msg_snapshot_restore_watch_helper_watch_event import ClusterAutoMsgSnapshotRestoreWatchHelperWatchEvent
from pensando_dss.psm.model.cluster_auto_msg_tenant_watch_helper import ClusterAutoMsgTenantWatchHelper
from pensando_dss.psm.model.cluster_auto_msg_tenant_watch_helper_watch_event import ClusterAutoMsgTenantWatchHelperWatchEvent
from pensando_dss.psm.model.cluster_auto_msg_version_watch_helper import ClusterAutoMsgVersionWatchHelper
from pensando_dss.psm.model.cluster_auto_msg_version_watch_helper_watch_event import ClusterAutoMsgVersionWatchHelperWatchEvent
from pensando_dss.psm.model.cluster_bios_info import ClusterBiosInfo
from pensando_dss.psm.model.cluster_cpu_info import ClusterCPUInfo
from pensando_dss.psm.model.cluster_cluster import ClusterCluster
from pensando_dss.psm.model.cluster_cluster_auth_bootstrap_request import ClusterClusterAuthBootstrapRequest
from pensando_dss.psm.model.cluster_cluster_condition import ClusterClusterCondition
from pensando_dss.psm.model.cluster_cluster_list import ClusterClusterList
from pensando_dss.psm.model.cluster_cluster_profile import ClusterClusterProfile
from pensando_dss.psm.model.cluster_cluster_profile_list import ClusterClusterProfileList
from pensando_dss.psm.model.cluster_cluster_profile_spec import ClusterClusterProfileSpec
from pensando_dss.psm.model.cluster_cluster_spec import ClusterClusterSpec
from pensando_dss.psm.model.cluster_cluster_status import ClusterClusterStatus
from pensando_dss.psm.model.cluster_configuration_snapshot import ClusterConfigurationSnapshot
from pensando_dss.psm.model.cluster_configuration_snapshot_list import ClusterConfigurationSnapshotList
from pensando_dss.psm.model.cluster_configuration_snapshot_request import ClusterConfigurationSnapshotRequest
from pensando_dss.psm.model.cluster_configuration_snapshot_spec import ClusterConfigurationSnapshotSpec
from pensando_dss.psm.model.cluster_configuration_snapshot_status import ClusterConfigurationSnapshotStatus
from pensando_dss.psm.model.cluster_credentials import ClusterCredentials
from pensando_dss.psm.model.cluster_credentials_list import ClusterCredentialsList
from pensando_dss.psm.model.cluster_credentials_spec import ClusterCredentialsSpec
from pensando_dss.psm.model.cluster_dsc_condition import ClusterDSCCondition
from pensando_dss.psm.model.cluster_dsc_control_plane_status import ClusterDSCControlPlaneStatus
from pensando_dss.psm.model.cluster_dsc_info import ClusterDSCInfo
from pensando_dss.psm.model.cluster_dsc_profile import ClusterDSCProfile
from pensando_dss.psm.model.cluster_dsc_profile_list import ClusterDSCProfileList
from pensando_dss.psm.model.cluster_dsc_profile_spec import ClusterDSCProfileSpec
from pensando_dss.psm.model.cluster_dsc_profile_status import ClusterDSCProfileStatus
from pensando_dss.psm.model.cluster_dsm import ClusterDSM
from pensando_dss.psm.model.cluster_dss_info import ClusterDSSInfo
from pensando_dss.psm.model.cluster_distributed_service_card import ClusterDistributedServiceCard
from pensando_dss.psm.model.cluster_distributed_service_card_id import ClusterDistributedServiceCardID
from pensando_dss.psm.model.cluster_distributed_service_card_list import ClusterDistributedServiceCardList
from pensando_dss.psm.model.cluster_distributed_service_card_spec import ClusterDistributedServiceCardSpec
from pensando_dss.psm.model.cluster_distributed_service_card_status import ClusterDistributedServiceCardStatus
from pensando_dss.psm.model.cluster_distributed_service_entity import ClusterDistributedServiceEntity
from pensando_dss.psm.model.cluster_distributed_service_entity_list import ClusterDistributedServiceEntityList
from pensando_dss.psm.model.cluster_distributed_service_entity_spec import ClusterDistributedServiceEntitySpec
from pensando_dss.psm.model.cluster_distributed_service_entity_status import ClusterDistributedServiceEntityStatus
from pensando_dss.psm.model.cluster_fault import ClusterFault
from pensando_dss.psm.model.cluster_feature import ClusterFeature
from pensando_dss.psm.model.cluster_feature_status import ClusterFeatureStatus
from pensando_dss.psm.model.cluster_flow_export_policy_ref import ClusterFlowExportPolicyRef
from pensando_dss.psm.model.cluster_fwlog_policy_ref import ClusterFwlogPolicyRef
from pensando_dss.psm.model.cluster_host import ClusterHost
from pensando_dss.psm.model.cluster_host_list import ClusterHostList
from pensando_dss.psm.model.cluster_host_spec import ClusterHostSpec
from pensando_dss.psm.model.cluster_host_status import ClusterHostStatus
from pensando_dss.psm.model.cluster_ip_config import ClusterIPConfig
from pensando_dss.psm.model.cluster_key_value import ClusterKeyValue
from pensando_dss.psm.model.cluster_license import ClusterLicense
from pensando_dss.psm.model.cluster_license_list import ClusterLicenseList
from pensando_dss.psm.model.cluster_license_spec import ClusterLicenseSpec
from pensando_dss.psm.model.cluster_license_status import ClusterLicenseStatus
from pensando_dss.psm.model.cluster_mem_info import ClusterMemInfo
from pensando_dss.psm.model.cluster_neighbor_port_info import ClusterNeighborPortInfo
from pensando_dss.psm.model.cluster_node import ClusterNode
from pensando_dss.psm.model.cluster_node_condition import ClusterNodeCondition
from pensando_dss.psm.model.cluster_node_list import ClusterNodeList
from pensando_dss.psm.model.cluster_node_spec import ClusterNodeSpec
from pensando_dss.psm.model.cluster_node_status import ClusterNodeStatus
from pensando_dss.psm.model.cluster_os_info import ClusterOsInfo
from pensando_dss.psm.model.cluster_overlay_forwarding import ClusterOverlayForwarding
from pensando_dss.psm.model.cluster_peer import ClusterPeer
from pensando_dss.psm.model.cluster_peer_status import ClusterPeerStatus
from pensando_dss.psm.model.cluster_pnic_info import ClusterPnicInfo
from pensando_dss.psm.model.cluster_policer_ref import ClusterPolicerRef
from pensando_dss.psm.model.cluster_propagation_status import ClusterPropagationStatus
from pensando_dss.psm.model.cluster_quorum_member_condition import ClusterQuorumMemberCondition
from pensando_dss.psm.model.cluster_quorum_member_status import ClusterQuorumMemberStatus
from pensando_dss.psm.model.cluster_quorum_status import ClusterQuorumStatus
from pensando_dss.psm.model.cluster_search_options import ClusterSearchOptions
from pensando_dss.psm.model.cluster_snapshot_destination import ClusterSnapshotDestination
from pensando_dss.psm.model.cluster_snapshot_restore import ClusterSnapshotRestore
from pensando_dss.psm.model.cluster_snapshot_restore_list import ClusterSnapshotRestoreList
from pensando_dss.psm.model.cluster_snapshot_restore_spec import ClusterSnapshotRestoreSpec
from pensando_dss.psm.model.cluster_snapshot_restore_status import ClusterSnapshotRestoreStatus
from pensando_dss.psm.model.cluster_storage_device_info import ClusterStorageDeviceInfo
from pensando_dss.psm.model.cluster_storage_info import ClusterStorageInfo
from pensando_dss.psm.model.cluster_tenant import ClusterTenant
from pensando_dss.psm.model.cluster_tenant_list import ClusterTenantList
from pensando_dss.psm.model.cluster_tenant_spec import ClusterTenantSpec
from pensando_dss.psm.model.cluster_update_tls_config_request import ClusterUpdateTLSConfigRequest
from pensando_dss.psm.model.cluster_version import ClusterVersion
from pensando_dss.psm.model.cluster_version_list import ClusterVersionList
from pensando_dss.psm.model.cluster_version_spec import ClusterVersionSpec
from pensando_dss.psm.model.cluster_version_status import ClusterVersionStatus
from pensando_dss.psm.model.configuration_snapshot_status_config_save_status import ConfigurationSnapshotStatusConfigSaveStatus
from pensando_dss.psm.model.dsc_profile_spec_interfaces import DSCProfileSpecInterfaces
from pensando_dss.psm.model.googleprotobuf_any import GoogleprotobufAny
from pensando_dss.psm.model.recoverykeys_recovery_keys import RecoverykeysRecoveryKeys



"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.security_v1_api import SecurityV1Api  # noqa: E501


class TestSecurityV1Api(unittest.TestCase):
    """SecurityV1Api unit test stubs"""

    def setUp(self):
        self.api = SecurityV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_app(self):
        """Test case for add_app

        Create App object  # noqa: E501
        """
        pass

    def test_add_app1(self):
        """Test case for add_app1

        Create App object  # noqa: E501
        """
        pass

    def test_add_ip_sec_policy(self):
        """Test case for add_ip_sec_policy

        Create IPSecPolicy object  # noqa: E501
        """
        pass

    def test_add_ip_sec_policy1(self):
        """Test case for add_ip_sec_policy1

        Create IPSecPolicy object  # noqa: E501
        """
        pass

    def test_add_network_security_policy(self):
        """Test case for add_network_security_policy

        Create NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_add_network_security_policy1(self):
        """Test case for add_network_security_policy1

        Create NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_delete_app(self):
        """Test case for delete_app

        Delete App object  # noqa: E501
        """
        pass

    def test_delete_app1(self):
        """Test case for delete_app1

        Delete App object  # noqa: E501
        """
        pass

    def test_delete_ip_sec_policy(self):
        """Test case for delete_ip_sec_policy

        Delete IPSecPolicy object  # noqa: E501
        """
        pass

    def test_delete_ip_sec_policy1(self):
        """Test case for delete_ip_sec_policy1

        Delete IPSecPolicy object  # noqa: E501
        """
        pass

    def test_delete_network_security_policy(self):
        """Test case for delete_network_security_policy

        Delete NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_delete_network_security_policy1(self):
        """Test case for delete_network_security_policy1

        Delete NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_get_app(self):
        """Test case for get_app

        Get App object  # noqa: E501
        """
        pass

    def test_get_app1(self):
        """Test case for get_app1

        Get App object  # noqa: E501
        """
        pass

    def test_get_firewall_profile(self):
        """Test case for get_firewall_profile

        Get FirewallProfile object  # noqa: E501
        """
        pass

    def test_get_firewall_profile1(self):
        """Test case for get_firewall_profile1

        Get FirewallProfile object  # noqa: E501
        """
        pass

    def test_get_ip_sec_policy(self):
        """Test case for get_ip_sec_policy

        Get IPSecPolicy object  # noqa: E501
        """
        pass

    def test_get_ip_sec_policy1(self):
        """Test case for get_ip_sec_policy1

        Get IPSecPolicy object  # noqa: E501
        """
        pass

    def test_get_network_security_policy(self):
        """Test case for get_network_security_policy

        Get NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_get_network_security_policy1(self):
        """Test case for get_network_security_policy1

        Get NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_label_app(self):
        """Test case for label_app

        Label App object  # noqa: E501
        """
        pass

    def test_label_app1(self):
        """Test case for label_app1

        Label App object  # noqa: E501
        """
        pass

    def test_label_firewall_profile(self):
        """Test case for label_firewall_profile

        Label FirewallProfile object  # noqa: E501
        """
        pass

    def test_label_firewall_profile1(self):
        """Test case for label_firewall_profile1

        Label FirewallProfile object  # noqa: E501
        """
        pass

    def test_label_ip_sec_policy(self):
        """Test case for label_ip_sec_policy

        Label IPSecPolicy object  # noqa: E501
        """
        pass

    def test_label_ip_sec_policy1(self):
        """Test case for label_ip_sec_policy1

        Label IPSecPolicy object  # noqa: E501
        """
        pass

    def test_label_network_security_policy(self):
        """Test case for label_network_security_policy

        Label NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_label_network_security_policy1(self):
        """Test case for label_network_security_policy1

        Label NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_list_app(self):
        """Test case for list_app

        List App objects  # noqa: E501
        """
        pass

    def test_list_app1(self):
        """Test case for list_app1

        List App objects  # noqa: E501
        """
        pass

    def test_list_firewall_profile(self):
        """Test case for list_firewall_profile

        List FirewallProfile objects  # noqa: E501
        """
        pass

    def test_list_firewall_profile1(self):
        """Test case for list_firewall_profile1

        List FirewallProfile objects  # noqa: E501
        """
        pass

    def test_list_ip_sec_policy(self):
        """Test case for list_ip_sec_policy

        List IPSecPolicy objects  # noqa: E501
        """
        pass

    def test_list_ip_sec_policy1(self):
        """Test case for list_ip_sec_policy1

        List IPSecPolicy objects  # noqa: E501
        """
        pass

    def test_list_network_security_policy(self):
        """Test case for list_network_security_policy

        List NetworkSecurityPolicy objects  # noqa: E501
        """
        pass

    def test_list_network_security_policy1(self):
        """Test case for list_network_security_policy1

        List NetworkSecurityPolicy objects  # noqa: E501
        """
        pass

    def test_update_app(self):
        """Test case for update_app

        Update App object  # noqa: E501
        """
        pass

    def test_update_app1(self):
        """Test case for update_app1

        Update App object  # noqa: E501
        """
        pass

    def test_update_firewall_profile(self):
        """Test case for update_firewall_profile

        Update FirewallProfile object  # noqa: E501
        """
        pass

    def test_update_firewall_profile1(self):
        """Test case for update_firewall_profile1

        Update FirewallProfile object  # noqa: E501
        """
        pass

    def test_update_ip_sec_policy(self):
        """Test case for update_ip_sec_policy

        Update IPSecPolicy object  # noqa: E501
        """
        pass

    def test_update_ip_sec_policy1(self):
        """Test case for update_ip_sec_policy1

        Update IPSecPolicy object  # noqa: E501
        """
        pass

    def test_update_network_security_policy(self):
        """Test case for update_network_security_policy

        Update NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_update_network_security_policy1(self):
        """Test case for update_network_security_policy1

        Update NetworkSecurityPolicy object  # noqa: E501
        """
        pass

    def test_watch_app(self):
        """Test case for watch_app

        Watch App objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_app1(self):
        """Test case for watch_app1

        Watch App objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_firewall_profile(self):
        """Test case for watch_firewall_profile

        Watch FirewallProfile objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_firewall_profile1(self):
        """Test case for watch_firewall_profile1

        Watch FirewallProfile objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_ip_sec_policy(self):
        """Test case for watch_ip_sec_policy

        Watch IPSecPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_ip_sec_policy1(self):
        """Test case for watch_ip_sec_policy1

        Watch IPSecPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_network_security_policy(self):
        """Test case for watch_network_security_policy

        Watch NetworkSecurityPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_network_security_policy1(self):
        """Test case for watch_network_security_policy1

        Watch NetworkSecurityPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from psm.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from pensando_dss.psm.model.api_agg_watch_options import ApiAggWatchOptions
from pensando_dss.psm.model.api_bgp_asn import ApiBgpAsn
from pensando_dss.psm.model.api_kind_watch_options import ApiKindWatchOptions
from pensando_dss.psm.model.api_label import ApiLabel
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.api_list_watch_options import ApiListWatchOptions
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.api_object_ref import ApiObjectRef
from pensando_dss.psm.model.api_rd_admin_value import ApiRDAdminValue
from pensando_dss.psm.model.api_status import ApiStatus
from pensando_dss.psm.model.api_status_result import ApiStatusResult
from pensando_dss.psm.model.api_timestamp import ApiTimestamp
from pensando_dss.psm.model.api_type_meta import ApiTypeMeta
from pensando_dss.psm.model.api_watch_control import ApiWatchControl
from pensando_dss.psm.model.api_watch_event import ApiWatchEvent
from pensando_dss.psm.model.api_watch_event_list import ApiWatchEventList
from pensando_dss.psm.model.cluster_ip_config import ClusterIPConfig
from pensando_dss.psm.model.googleprotobuf_any import GoogleprotobufAny
from pensando_dss.psm.model.network_add_static_bindings_request import NetworkAddStaticBindingsRequest
from pensando_dss.psm.model.network_auto_msg_ipam_policy_watch_helper import NetworkAutoMsgIPAMPolicyWatchHelper
from pensando_dss.psm.model.network_auto_msg_ipam_policy_watch_helper_watch_event import NetworkAutoMsgIPAMPolicyWatchHelperWatchEvent
from pensando_dss.psm.model.network_auto_msg_lb_policy_watch_helper import NetworkAutoMsgLbPolicyWatchHelper
from pensando_dss.psm.model.network_auto_msg_lb_policy_watch_helper_watch_event import NetworkAutoMsgLbPolicyWatchHelperWatchEvent
from pensando_dss.psm.model.network_auto_msg_network_interface_watch_helper import NetworkAutoMsgNetworkInterfaceWatchHelper
from pensando_dss.psm.model.network_auto_msg_network_interface_watch_helper_watch_event import NetworkAutoMsgNetworkInterfaceWatchHelperWatchEvent
from pensando_dss.psm.model.network_auto_msg_network_watch_helper import NetworkAutoMsgNetworkWatchHelper
from pensando_dss.psm.model.network_auto_msg_network_watch_helper_watch_event import NetworkAutoMsgNetworkWatchHelperWatchEvent
from pensando_dss.psm.model.network_auto_msg_policer_profile_watch_helper import NetworkAutoMsgPolicerProfileWatchHelper
from pensando_dss.psm.model.network_auto_msg_policer_profile_watch_helper_watch_event import NetworkAutoMsgPolicerProfileWatchHelperWatchEvent
from pensando_dss.psm.model.network_auto_msg_route_table_watch_helper import NetworkAutoMsgRouteTableWatchHelper
from pensando_dss.psm.model.network_auto_msg_route_table_watch_helper_watch_event import NetworkAutoMsgRouteTableWatchHelperWatchEvent
from pensando_dss.psm.model.network_auto_msg_routing_config_watch_helper import NetworkAutoMsgRoutingConfigWatchHelper
from pensando_dss.psm.model.network_auto_msg_routing_config_watch_helper_watch_event import NetworkAutoMsgRoutingConfigWatchHelperWatchEvent
from pensando_dss.psm.model.network_auto_msg_service_watch_helper import NetworkAutoMsgServiceWatchHelper
from pensando_dss.psm.model.network_auto_msg_service_watch_helper_watch_event import NetworkAutoMsgServiceWatchHelperWatchEvent
from pensando_dss.psm.model.network_auto_msg_virtual_router_peering_group_watch_helper import NetworkAutoMsgVirtualRouterPeeringGroupWatchHelper
from pensando_dss.psm.model.network_auto_msg_virtual_router_peering_group_watch_helper_watch_event import NetworkAutoMsgVirtualRouterPeeringGroupWatchHelperWatchEvent
from pensando_dss.psm.model.network_auto_msg_virtual_router_watch_helper import NetworkAutoMsgVirtualRouterWatchHelper
from pensando_dss.psm.model.network_auto_msg_virtual_router_watch_helper_watch_event import NetworkAutoMsgVirtualRouterWatchHelperWatchEvent
from pensando_dss.psm.model.network_bgp_auth_status import NetworkBGPAuthStatus
from pensando_dss.psm.model.network_bgp_config import NetworkBGPConfig
from pensando_dss.psm.model.network_bgp_neighbor import NetworkBGPNeighbor
from pensando_dss.psm.model.network_bootstrap_ipam_options import NetworkBootstrapIPAMOptions
from pensando_dss.psm.model.network_classless_static_route import NetworkClasslessStaticRoute
from pensando_dss.psm.model.network_dhcp_relay_policy import NetworkDHCPRelayPolicy
from pensando_dss.psm.model.network_dhcp_server import NetworkDHCPServer
from pensando_dss.psm.model.network_health_check_spec import NetworkHealthCheckSpec
from pensando_dss.psm.model.network_ipam_binding import NetworkIPAMBinding
from pensando_dss.psm.model.network_ipam_config import NetworkIPAMConfig
from pensando_dss.psm.model.network_ipam_options import NetworkIPAMOptions
from pensando_dss.psm.model.network_ipam_policy import NetworkIPAMPolicy
from pensando_dss.psm.model.network_ipam_policy_list import NetworkIPAMPolicyList
from pensando_dss.psm.model.network_ipam_policy_spec import NetworkIPAMPolicySpec
from pensando_dss.psm.model.network_ipam_policy_status import NetworkIPAMPolicyStatus
from pensando_dss.psm.model.network_ipam_pool_info import NetworkIPAMPoolInfo
from pensando_dss.psm.model.network_interface_ip import NetworkInterfaceIP
from pensando_dss.psm.model.network_lldp_neighbor import NetworkLLDPNeighbor
from pensando_dss.psm.model.network_lb_policy import NetworkLbPolicy
from pensando_dss.psm.model.network_lb_policy_list import NetworkLbPolicyList
from pensando_dss.psm.model.network_lb_policy_spec import NetworkLbPolicySpec
from pensando_dss.psm.model.network_lb_policy_status import NetworkLbPolicyStatus
from pensando_dss.psm.model.network_network import NetworkNetwork
from pensando_dss.psm.model.network_network_firewall_profile import NetworkNetworkFirewallProfile
from pensando_dss.psm.model.network_network_interface import NetworkNetworkInterface
from pensando_dss.psm.model.network_network_interface_host_status import NetworkNetworkInterfaceHostStatus
from pensando_dss.psm.model.network_network_interface_list import NetworkNetworkInterfaceList
from pensando_dss.psm.model.network_network_interface_spec import NetworkNetworkInterfaceSpec
from pensando_dss.psm.model.network_network_interface_status import NetworkNetworkInterfaceStatus
from pensando_dss.psm.model.network_network_interface_uplink_status import NetworkNetworkInterfaceUplinkStatus
from pensando_dss.psm.model.network_network_list import NetworkNetworkList
from pensando_dss.psm.model.network_network_spec import NetworkNetworkSpec
from pensando_dss.psm.model.network_network_status import NetworkNetworkStatus
from pensando_dss.psm.model.network_orchestrator_info import NetworkOrchestratorInfo
from pensando_dss.psm.model.network_pause_spec import NetworkPauseSpec
from pensando_dss.psm.model.network_policer_action import NetworkPolicerAction
from pensando_dss.psm.model.network_policer_criteria import NetworkPolicerCriteria
from pensando_dss.psm.model.network_policer_profile import NetworkPolicerProfile
from pensando_dss.psm.model.network_policer_profile_list import NetworkPolicerProfileList
from pensando_dss.psm.model.network_policer_profile_spec import NetworkPolicerProfileSpec
from pensando_dss.psm.model.network_policer_profile_status import NetworkPolicerProfileStatus
from pensando_dss.psm.model.network_policy_reference import NetworkPolicyReference
from pensando_dss.psm.model.network_rd_spec import NetworkRDSpec
from pensando_dss.psm.model.network_route import NetworkRoute
from pensando_dss.psm.model.network_route_distinguisher import NetworkRouteDistinguisher
from pensando_dss.psm.model.network_route_table import NetworkRouteTable
from pensando_dss.psm.model.network_route_table_list import NetworkRouteTableList
from pensando_dss.psm.model.network_route_table_status import NetworkRouteTableStatus
from pensando_dss.psm.model.network_routing_config import NetworkRoutingConfig
from pensando_dss.psm.model.network_routing_config_list import NetworkRoutingConfigList
from pensando_dss.psm.model.network_routing_config_spec import NetworkRoutingConfigSpec
from pensando_dss.psm.model.network_routing_config_status import NetworkRoutingConfigStatus
from pensando_dss.psm.model.network_security_policy_status import NetworkSecurityPolicyStatus
from pensando_dss.psm.model.network_service import NetworkService
from pensando_dss.psm.model.network_service_list import NetworkServiceList
from pensando_dss.psm.model.network_service_spec import NetworkServiceSpec
from pensando_dss.psm.model.network_service_status import NetworkServiceStatus
from pensando_dss.psm.model.network_tls_client_policy_spec import NetworkTLSClientPolicySpec
from pensando_dss.psm.model.network_tls_server_policy_spec import NetworkTLSServerPolicySpec
from pensando_dss.psm.model.network_transceiver_status import NetworkTransceiverStatus
from pensando_dss.psm.model.network_virtual_router import NetworkVirtualRouter
from pensando_dss.psm.model.network_virtual_router_list import NetworkVirtualRouterList
from pensando_dss.psm.model.network_virtual_router_peering_group import NetworkVirtualRouterPeeringGroup
from pensando_dss.psm.model.network_virtual_router_peering_group_list import NetworkVirtualRouterPeeringGroupList
from pensando_dss.psm.model.network_virtual_router_peering_group_spec import NetworkVirtualRouterPeeringGroupSpec
from pensando_dss.psm.model.network_virtual_router_peering_group_status import NetworkVirtualRouterPeeringGroupStatus
from pensando_dss.psm.model.network_virtual_router_peering_route import NetworkVirtualRouterPeeringRoute
from pensando_dss.psm.model.network_virtual_router_peering_route_table import NetworkVirtualRouterPeeringRouteTable
from pensando_dss.psm.model.network_virtual_router_peering_spec import NetworkVirtualRouterPeeringSpec
from pensando_dss.psm.model.network_virtual_router_spec import NetworkVirtualRouterSpec
from pensando_dss.psm.model.network_virtual_router_status import NetworkVirtualRouterStatus
from pensando_dss.psm.model.security_dsc_status import SecurityDSCStatus
from pensando_dss.psm.model.security_propagation_status import SecurityPropagationStatus



"""
    Workload API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.workload_propagation_status import WorkloadPropagationStatus
from pensando_dss.psm.model.workload_workload_intf_status import WorkloadWorkloadIntfStatus
from pensando_dss.psm.model.workload_workload_migration_status import WorkloadWorkloadMigrationStatus
globals()['WorkloadPropagationStatus'] = WorkloadPropagationStatus
globals()['WorkloadWorkloadIntfStatus'] = WorkloadWorkloadIntfStatus
globals()['WorkloadWorkloadMigrationStatus'] = WorkloadWorkloadMigrationStatus
from pensando_dss.psm.psm.model.workload_workload_status import WorkloadWorkloadStatus


class TestWorkloadWorkloadStatus(unittest.TestCase):
    """WorkloadWorkloadStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testWorkloadWorkloadStatus(self):
        """Test WorkloadWorkloadStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = WorkloadWorkloadStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from psm.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from pensando_dss.psm.model.api_agg_watch_options import ApiAggWatchOptions
from pensando_dss.psm.model.api_dse_status import ApiDSEStatus
from pensando_dss.psm.model.api_kind_watch_options import ApiKindWatchOptions
from pensando_dss.psm.model.api_label import ApiLabel
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.api_list_watch_options import ApiListWatchOptions
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.api_object_ref import ApiObjectRef
from pensando_dss.psm.model.api_propagation_status import ApiPropagationStatus
from pensando_dss.psm.model.api_status import ApiStatus
from pensando_dss.psm.model.api_status_result import ApiStatusResult
from pensando_dss.psm.model.api_timestamp import ApiTimestamp
from pensando_dss.psm.model.api_type_meta import ApiTypeMeta
from pensando_dss.psm.model.api_watch_control import ApiWatchControl
from pensando_dss.psm.model.api_watch_event import ApiWatchEvent
from pensando_dss.psm.model.api_watch_event_list import ApiWatchEventList
from pensando_dss.psm.model.cluster_ip_config import ClusterIPConfig
from pensando_dss.psm.model.googleprotobuf_any import GoogleprotobufAny
from pensando_dss.psm.model.labels_requirement import LabelsRequirement
from pensando_dss.psm.model.labels_selector import LabelsSelector
from pensando_dss.psm.model.workload_auto_msg_endpoint_watch_helper import WorkloadAutoMsgEndpointWatchHelper
from pensando_dss.psm.model.workload_auto_msg_endpoint_watch_helper_watch_event import WorkloadAutoMsgEndpointWatchHelperWatchEvent
from pensando_dss.psm.model.workload_auto_msg_workload_group_watch_helper import WorkloadAutoMsgWorkloadGroupWatchHelper
from pensando_dss.psm.model.workload_auto_msg_workload_group_watch_helper_watch_event import WorkloadAutoMsgWorkloadGroupWatchHelperWatchEvent
from pensando_dss.psm.model.workload_auto_msg_workload_watch_helper import WorkloadAutoMsgWorkloadWatchHelper
from pensando_dss.psm.model.workload_auto_msg_workload_watch_helper_watch_event import WorkloadAutoMsgWorkloadWatchHelperWatchEvent
from pensando_dss.psm.model.workload_endpoint import WorkloadEndpoint
from pensando_dss.psm.model.workload_endpoint_list import WorkloadEndpointList
from pensando_dss.psm.model.workload_endpoint_migration_status import WorkloadEndpointMigrationStatus
from pensando_dss.psm.model.workload_endpoint_prop_status import WorkloadEndpointPropStatus
from pensando_dss.psm.model.workload_endpoint_spec import WorkloadEndpointSpec
from pensando_dss.psm.model.workload_endpoint_status import WorkloadEndpointStatus
from pensando_dss.psm.model.workload_ip_block import WorkloadIPBlock
from pensando_dss.psm.model.workload_interface_migration_status import WorkloadInterfaceMigrationStatus
from pensando_dss.psm.model.workload_migration_source import WorkloadMigrationSource
from pensando_dss.psm.model.workload_propagation_status import WorkloadPropagationStatus
from pensando_dss.psm.model.workload_workload import WorkloadWorkload
from pensando_dss.psm.model.workload_workload_group import WorkloadWorkloadGroup
from pensando_dss.psm.model.workload_workload_group_list import WorkloadWorkloadGroupList
from pensando_dss.psm.model.workload_workload_group_spec import WorkloadWorkloadGroupSpec
from pensando_dss.psm.model.workload_workload_group_status import WorkloadWorkloadGroupStatus
from pensando_dss.psm.model.workload_workload_intf_spec import WorkloadWorkloadIntfSpec
from pensando_dss.psm.model.workload_workload_intf_status import WorkloadWorkloadIntfStatus
from pensando_dss.psm.model.workload_workload_list import WorkloadWorkloadList
from pensando_dss.psm.model.workload_workload_migration_status import WorkloadWorkloadMigrationStatus
from pensando_dss.psm.model.workload_workload_spec import WorkloadWorkloadSpec
from pensando_dss.psm.model.workload_workload_status import WorkloadWorkloadStatus



"""
    Monitoring API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.monitoring_interface_mirror import MonitoringInterfaceMirror
from pensando_dss.psm.model.monitoring_match_rule import MonitoringMatchRule
from pensando_dss.psm.model.monitoring_mirror_collector import MonitoringMirrorCollector
from pensando_dss.psm.model.monitoring_mirror_source import MonitoringMirrorSource
from pensando_dss.psm.model.monitoring_mirror_start_conditions import MonitoringMirrorStartConditions
from pensando_dss.psm.model.monitoring_workload_mirror import MonitoringWorkloadMirror
globals()['MonitoringInterfaceMirror'] = MonitoringInterfaceMirror
globals()['MonitoringMatchRule'] = MonitoringMatchRule
globals()['MonitoringMirrorCollector'] = MonitoringMirrorCollector
globals()['MonitoringMirrorSource'] = MonitoringMirrorSource
globals()['MonitoringMirrorStartConditions'] = MonitoringMirrorStartConditions
globals()['MonitoringWorkloadMirror'] = MonitoringWorkloadMirror
from pensando_dss.psm.psm.model.monitoring_mirror_session_spec import MonitoringMirrorSessionSpec


class TestMonitoringMirrorSessionSpec(unittest.TestCase):
    """MonitoringMirrorSessionSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMonitoringMirrorSessionSpec(self):
        """Test MonitoringMirrorSessionSpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MonitoringMirrorSessionSpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.cluster_ip_config import ClusterIPConfig
from pensando_dss.psm.model.network_pause_spec import NetworkPauseSpec
globals()['ClusterIPConfig'] = ClusterIPConfig
globals()['NetworkPauseSpec'] = NetworkPauseSpec
from pensando_dss.psm.psm.model.network_network_interface_spec import NetworkNetworkInterfaceSpec


class TestNetworkNetworkInterfaceSpec(unittest.TestCase):
    """NetworkNetworkInterfaceSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkNetworkInterfaceSpec(self):
        """Test NetworkNetworkInterfaceSpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkNetworkInterfaceSpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from psm.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from pensando_dss.psm.model.api_agg_watch_options import ApiAggWatchOptions
from pensando_dss.psm.model.api_kind_watch_options import ApiKindWatchOptions
from pensando_dss.psm.model.api_label import ApiLabel
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.api_list_watch_options import ApiListWatchOptions
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.api_object_ref import ApiObjectRef
from pensando_dss.psm.model.api_status import ApiStatus
from pensando_dss.psm.model.api_status_result import ApiStatusResult
from pensando_dss.psm.model.api_timestamp import ApiTimestamp
from pensando_dss.psm.model.api_type_meta import ApiTypeMeta
from pensando_dss.psm.model.api_watch_control import ApiWatchControl
from pensando_dss.psm.model.api_watch_event import ApiWatchEvent
from pensando_dss.psm.model.api_watch_event_list import ApiWatchEventList
from pensando_dss.psm.model.auth_authentication_policy import AuthAuthenticationPolicy
from pensando_dss.psm.model.auth_authentication_policy_list import AuthAuthenticationPolicyList
from pensando_dss.psm.model.auth_authentication_policy_spec import AuthAuthenticationPolicySpec
from pensando_dss.psm.model.auth_authentication_policy_status import AuthAuthenticationPolicyStatus
from pensando_dss.psm.model.auth_authenticators import AuthAuthenticators
from pensando_dss.psm.model.auth_auto_msg_authentication_policy_watch_helper import AuthAutoMsgAuthenticationPolicyWatchHelper
from pensando_dss.psm.model.auth_auto_msg_authentication_policy_watch_helper_watch_event import AuthAutoMsgAuthenticationPolicyWatchHelperWatchEvent
from pensando_dss.psm.model.auth_auto_msg_role_binding_watch_helper import AuthAutoMsgRoleBindingWatchHelper
from pensando_dss.psm.model.auth_auto_msg_role_binding_watch_helper_watch_event import AuthAutoMsgRoleBindingWatchHelperWatchEvent
from pensando_dss.psm.model.auth_auto_msg_role_watch_helper import AuthAutoMsgRoleWatchHelper
from pensando_dss.psm.model.auth_auto_msg_role_watch_helper_watch_event import AuthAutoMsgRoleWatchHelperWatchEvent
from pensando_dss.psm.model.auth_auto_msg_user_preference_watch_helper import AuthAutoMsgUserPreferenceWatchHelper
from pensando_dss.psm.model.auth_auto_msg_user_preference_watch_helper_watch_event import AuthAutoMsgUserPreferenceWatchHelperWatchEvent
from pensando_dss.psm.model.auth_auto_msg_user_watch_helper import AuthAutoMsgUserWatchHelper
from pensando_dss.psm.model.auth_auto_msg_user_watch_helper_watch_event import AuthAutoMsgUserWatchHelperWatchEvent
from pensando_dss.psm.model.auth_ldap import AuthLdap
from pensando_dss.psm.model.auth_ldap_attribute_mapping import AuthLdapAttributeMapping
from pensando_dss.psm.model.auth_ldap_domain import AuthLdapDomain
from pensando_dss.psm.model.auth_ldap_server import AuthLdapServer
from pensando_dss.psm.model.auth_ldap_server_status import AuthLdapServerStatus
from pensando_dss.psm.model.auth_local import AuthLocal
from pensando_dss.psm.model.auth_operation import AuthOperation
from pensando_dss.psm.model.auth_operation_status import AuthOperationStatus
from pensando_dss.psm.model.auth_password_change_request import AuthPasswordChangeRequest
from pensando_dss.psm.model.auth_password_reset_request import AuthPasswordResetRequest
from pensando_dss.psm.model.auth_permission import AuthPermission
from pensando_dss.psm.model.auth_radius import AuthRadius
from pensando_dss.psm.model.auth_radius_domain import AuthRadiusDomain
from pensando_dss.psm.model.auth_radius_server import AuthRadiusServer
from pensando_dss.psm.model.auth_radius_server_status import AuthRadiusServerStatus
from pensando_dss.psm.model.auth_resource import AuthResource
from pensando_dss.psm.model.auth_role import AuthRole
from pensando_dss.psm.model.auth_role_binding import AuthRoleBinding
from pensando_dss.psm.model.auth_role_binding_list import AuthRoleBindingList
from pensando_dss.psm.model.auth_role_binding_spec import AuthRoleBindingSpec
from pensando_dss.psm.model.auth_role_list import AuthRoleList
from pensando_dss.psm.model.auth_role_spec import AuthRoleSpec
from pensando_dss.psm.model.auth_subject_access_review_request import AuthSubjectAccessReviewRequest
from pensando_dss.psm.model.auth_tls_options import AuthTLSOptions
from pensando_dss.psm.model.auth_token_secret_request import AuthTokenSecretRequest
from pensando_dss.psm.model.auth_user import AuthUser
from pensando_dss.psm.model.auth_user_list import AuthUserList
from pensando_dss.psm.model.auth_user_preference import AuthUserPreference
from pensando_dss.psm.model.auth_user_preference_list import AuthUserPreferenceList
from pensando_dss.psm.model.auth_user_preference_spec import AuthUserPreferenceSpec
from pensando_dss.psm.model.auth_user_spec import AuthUserSpec
from pensando_dss.psm.model.auth_user_status import AuthUserStatus
from pensando_dss.psm.model.auth_user_unlock_request import AuthUserUnlockRequest
from pensando_dss.psm.model.googleprotobuf_any import GoogleprotobufAny



"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.network_auto_msg_route_table_watch_helper_watch_event import NetworkAutoMsgRouteTableWatchHelperWatchEvent
globals()['NetworkAutoMsgRouteTableWatchHelperWatchEvent'] = NetworkAutoMsgRouteTableWatchHelperWatchEvent
from pensando_dss.psm.psm.model.network_auto_msg_route_table_watch_helper import NetworkAutoMsgRouteTableWatchHelper


class TestNetworkAutoMsgRouteTableWatchHelper(unittest.TestCase):
    """NetworkAutoMsgRouteTableWatchHelper unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkAutoMsgRouteTableWatchHelper(self):
        """Test NetworkAutoMsgRouteTableWatchHelper"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkAutoMsgRouteTableWatchHelper()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Objstore API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.objstore_v1_api import ObjstoreV1Api  # noqa: E501


class TestObjstoreV1Api(unittest.TestCase):
    """ObjstoreV1Api unit test stubs"""

    def setUp(self):
        self.api = ObjstoreV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_object(self):
        """Test case for add_object

        Create Object object  # noqa: E501
        """
        pass

    def test_add_object1(self):
        """Test case for add_object1

        Create Object object  # noqa: E501
        """
        pass

    def test_delete_object(self):
        """Test case for delete_object

        Delete Object object  # noqa: E501
        """
        pass

    def test_delete_object1(self):
        """Test case for delete_object1

        Delete Object object  # noqa: E501
        """
        pass

    def test_get_download_file(self):
        """Test case for get_download_file

        Download file  # noqa: E501
        """
        pass

    def test_get_download_file1(self):
        """Test case for get_download_file1

        Download file  # noqa: E501
        """
        pass

    def test_get_download_file_by_prefix(self):
        """Test case for get_download_file_by_prefix

        Download file by prefix  # noqa: E501
        """
        pass

    def test_get_object(self):
        """Test case for get_object

        Get Object object  # noqa: E501
        """
        pass

    def test_get_object1(self):
        """Test case for get_object1

        Get Object object  # noqa: E501
        """
        pass

    def test_list_object(self):
        """Test case for list_object

        List Object objects  # noqa: E501
        """
        pass

    def test_list_object1(self):
        """Test case for list_object1

        List Object objects  # noqa: E501
        """
        pass

    def test_watch_object(self):
        """Test case for watch_object

        Watch Object objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_object1(self):
        """Test case for watch_object1

        Watch Object objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cluster API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.cluster_configuration_snapshot_spec import ClusterConfigurationSnapshotSpec
from pensando_dss.psm.model.cluster_configuration_snapshot_status import ClusterConfigurationSnapshotStatus
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['ClusterConfigurationSnapshotSpec'] = ClusterConfigurationSnapshotSpec
globals()['ClusterConfigurationSnapshotStatus'] = ClusterConfigurationSnapshotStatus
from pensando_dss.psm.psm.model.cluster_configuration_snapshot import ClusterConfigurationSnapshot


class TestClusterConfigurationSnapshot(unittest.TestCase):
    """ClusterConfigurationSnapshot unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClusterConfigurationSnapshot(self):
        """Test ClusterConfigurationSnapshot"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ClusterConfigurationSnapshot()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Monitoring API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.monitoring_alert_destination_spec import MonitoringAlertDestinationSpec
from pensando_dss.psm.model.monitoring_alert_destination_status import MonitoringAlertDestinationStatus
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['MonitoringAlertDestinationSpec'] = MonitoringAlertDestinationSpec
globals()['MonitoringAlertDestinationStatus'] = MonitoringAlertDestinationStatus
from pensando_dss.psm.psm.model.monitoring_alert_destination import MonitoringAlertDestination


class TestMonitoringAlertDestination(unittest.TestCase):
    """MonitoringAlertDestination unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMonitoringAlertDestination(self):
        """Test MonitoringAlertDestination"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MonitoringAlertDestination()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Events API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.events_v1_api import EventsV1Api  # noqa: E501


class TestEventsV1Api(unittest.TestCase):
    """EventsV1Api unit test stubs"""

    def setUp(self):
        self.api = EventsV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_get_event(self):
        """Test case for get_get_event

        Get specific event  # noqa: E501
        """
        pass

    def test_get_get_events1(self):
        """Test case for get_get_events1

        """
        pass

    def test_post_get_events(self):
        """Test case for post_get_events

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cluster API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.cluster_distributed_service_card_id import ClusterDistributedServiceCardID
from pensando_dss.psm.model.cluster_pnic_info import ClusterPnicInfo
globals()['ClusterDistributedServiceCardID'] = ClusterDistributedServiceCardID
globals()['ClusterPnicInfo'] = ClusterPnicInfo
from pensando_dss.psm.psm.model.cluster_host_spec import ClusterHostSpec


class TestClusterHostSpec(unittest.TestCase):
    """ClusterHostSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClusterHostSpec(self):
        """Test ClusterHostSpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ClusterHostSpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Monitoring API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.monitoring_fwlog_policy_spec import MonitoringFwlogPolicySpec
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['MonitoringFwlogPolicySpec'] = MonitoringFwlogPolicySpec
from pensando_dss.psm.psm.model.monitoring_fwlog_policy import MonitoringFwlogPolicy


class TestMonitoringFwlogPolicy(unittest.TestCase):
    """MonitoringFwlogPolicy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMonitoringFwlogPolicy(self):
        """Test MonitoringFwlogPolicy"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MonitoringFwlogPolicy()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cluster API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.cluster_dsc_condition import ClusterDSCCondition
from pensando_dss.psm.model.cluster_dsc_control_plane_status import ClusterDSCControlPlaneStatus
from pensando_dss.psm.model.cluster_dsc_info import ClusterDSCInfo
from pensando_dss.psm.model.cluster_dss_info import ClusterDSSInfo
from pensando_dss.psm.model.cluster_ip_config import ClusterIPConfig
globals()['ClusterDSCCondition'] = ClusterDSCCondition
globals()['ClusterDSCControlPlaneStatus'] = ClusterDSCControlPlaneStatus
globals()['ClusterDSCInfo'] = ClusterDSCInfo
globals()['ClusterDSSInfo'] = ClusterDSSInfo
globals()['ClusterIPConfig'] = ClusterIPConfig
from pensando_dss.psm.psm.model.cluster_distributed_service_card_status import ClusterDistributedServiceCardStatus


class TestClusterDistributedServiceCardStatus(unittest.TestCase):
    """ClusterDistributedServiceCardStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClusterDistributedServiceCardStatus(self):
        """Test ClusterDistributedServiceCardStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ClusterDistributedServiceCardStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
